@@ -4,7 +4,7 @@
 # pylint: disable=unused-import
 
 from . import py_version_check
-from .multiconf import McConfigRoot, AbstractConfigItem, ConfigItem, RepeatableConfigItem, ConfigBuilder
+from .multiconf import McConfigRoot, AbstractConfigItem, ConfigItem, RepeatableConfigItem, DefaultItems, ConfigBuilder
 from .decorators import mc_config
 from .config_errors import ConfigException, ConfigDefinitionException, ConfigApiException, InvalidUsageException
 from .config_errors import ConfigAttributeError, ConfigExcludedAttributeError, ConfigExcludedKeyError
@@ -13,7 +13,7 @@ from .values import MC_REQUIRED, MC_TODO, McInvalidValue, McTodoHandling
 
 
 __all__ = [
-    'mc_config', 'McConfigRoot', 'AbstractConfigItem', 'ConfigItem', 'RepeatableConfigItem', 'ConfigBuilder',
+    'mc_config', 'McConfigRoot', 'AbstractConfigItem', 'ConfigItem', 'RepeatableConfigItem', 'DefaultItems', 'ConfigBuilder',
     'ConfigException', 'ConfigDefinitionException', 'ConfigApiException', 'InvalidUsageException',
     'ConfigAttributeError', 'ConfigExcludedAttributeError',
     'MC_REQUIRED', 'MC_TODO', 'McInvalidValue', 'McTodoHandling',
